@@ -13,6 +13,14 @@
 
 static char *sourcepackagename = NULL;
 
+static gboolean
+have_program_in_path (const char *name)
+{
+    gchar *path = g_find_program_in_path (name);
+    g_free (path);
+    return path != NULL;
+}
+
 void
 launchpad_integration_set_sourcepackagename (const char *name)
 {
@@ -143,7 +151,7 @@ static GtkActionEntry actions[] = {
       N_("Translate This Application..."), NULL, 
       N_("Connect to the Launchpad website to help translate this application"),
       G_CALLBACK (launchpad_integration_show_translations) },
-#if 0
+#if 1 // Disable this on stable releases
     { "LaunchpadAppBugs", "lpi-bug",
       N_("Report a Problem..."), NULL, NULL, 
       G_CALLBACK (launchpad_integration_show_bugs) },
@@ -182,7 +190,7 @@ launchpad_integration_get_action_group (void)
 void
 launchpad_integration_add_ui (GtkUIManager *ui, const char *path)
 {
-    if (!g_find_program_in_path ("launchpad-integration")) {
+    if (!have_program_in_path ("launchpad-integration")) {
 	return;
     }
 
@@ -233,7 +241,7 @@ launchpad_integration_add_ui_with_separators (GtkUIManager *ui, const char *path
 					      gboolean separator_before,
 					      gboolean separator_after)
 {
-    if (!g_find_program_in_path ("launchpad-integration")) {
+    if (!have_program_in_path ("launchpad-integration")) {
 	return;
     }
 
@@ -298,7 +306,7 @@ launchpad_integration_add_items (GtkWidget *helpmenu, int position,
 				 gboolean separator_before,
 				 gboolean separator_after)
 {
-    if (!g_find_program_in_path ("launchpad-integration")) {
+    if (!have_program_in_path ("launchpad-integration")) {
 	return;
     }
 
